@@ -3,8 +3,8 @@ package Gscan2pdf::Config;
 use strict;
 use warnings;
 use Gscan2pdf::Document;
-use Glib qw(TRUE FALSE);     # To get TRUE and FALSE
-use Locale::gettext 1.05;    # For translations
+use Gscan2pdf::Translation '__';    # easier to extract strings with xgettext
+use Glib qw(TRUE FALSE);            # To get TRUE and FALSE
 use File::Copy;
 use Try::Tiny;
 use Data::Dumper;
@@ -16,7 +16,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '1.8.4';
+    $VERSION = '1.8.5';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -27,7 +27,6 @@ BEGIN {
 }
 
 my $EMPTY = q{};
-my $d;
 
 sub _pre_151 {
     my ( $version, $SETTING ) = @_;
@@ -119,10 +118,6 @@ sub read_config {
         Gscan2pdf::Document::exec_command( [ 'touch', $filename ] );
     }
 
-    if ( not defined $d ) {
-        $d = Locale::gettext->domain(Glib::get_application_name);
-    }
-
     # from v1.3.3 onwards, the config file is saved as JSON
     my $config  = Gscan2pdf::Document::slurp($filename);
     my $version = '2';
@@ -141,9 +136,7 @@ sub read_config {
         }
         catch {
             $logger->error(
-                $d->get(
 "Error: unable to load settings.\nBacking up settings\nReverting to defaults"
-                )
             );
             move( $filename, "$filename.old" );
         }
@@ -217,7 +210,6 @@ sub add_defaults {
         'Page range'                        => 'all',
         version                             => undef,
         'SANE version'                      => undef,
-        'libsane-perl version'              => undef,
         'libimage-sane-perl version'        => undef,
         selection                           => undef,
         cwd                                 => undef,
@@ -273,7 +265,7 @@ sub add_defaults {
         'ocr language' => undef,
         'OCR output' =>
           'replace',   # When a page is re-OCRed, replace old text with new text
-        ps_backend              => 'ghostscript',
+        ps_backend              => 'pdftops',
         user_defined_tools      => ['gimp %i'],
         udt_on_scan             => FALSE,
         current_udt             => undef,
@@ -283,19 +275,25 @@ sub add_defaults {
         'available-tmp-warning' => 10,
         close_dialog_on_save    => TRUE,
         'Paper'                 => {
-            $d->get('A4') => {
+            __('A3') => {
+                x => 297,
+                y => 420,
+                l => 0,
+                t => 0,
+            },
+            __('A4') => {
                 x => 210,
                 y => 297,
                 l => 0,
                 t => 0,
             },
-            $d->get('US Letter') => {
+            __('US Letter') => {
                 x => 216,
                 y => 279,
                 l => 0,
                 t => 0,
             },
-            $d->get('US Legal') => {
+            __('US Legal') => {
                 x => 216,
                 y => 356,
                 l => 0,
@@ -339,7 +337,7 @@ sub add_defaults {
     if (
         defined $SETTING->{frontend}
         and ( $SETTING->{frontend} !~
-            /^(?:scanimage|scanadf|libsane-perl|libimage-sane-perl)$/xsm )
+            /^(?:scanimage|scanadf|libimage-sane-perl)$/xsm )
       )
     {
         delete $SETTING->{frontend};
@@ -389,8 +387,8 @@ sub check_sane_version {
     {
         if ( defined $SETTING->{cache} ) { delete $SETTING->{cache} }
     }
-    $SETTING->{'SANE version'}         = $SANE;
-    $SETTING->{'libsane-perl version'} = $LIBSANEPERL;
+    $SETTING->{'SANE version'}               = $SANE;
+    $SETTING->{'libimage-sane-perl version'} = $LIBSANEPERL;
     return;
 }
 
